pysmug.methods

Package pysmug :: Module methods |
[hide private]
[frames] | no frames]

# Module methods

source code

Variables | [hide private]
| apikeys = ``{``'``albumkey``'``:` `'``AlbumKey``'``,` `'``apikey``'``:` `'``APIKey``'``,` `'``emaila``...``
| methods = ``set([``'``smugmug.albums.applyWatermark``'``,` `'``smugmug.album``...``

Variables Details | [hide private]

  ### apikeys Value:
      {'albumkey': 'AlbumKey',
       'apikey': 'APIKey',
       'emailaddress': 'EmailAddress',
       'filename': 'FileName',
       'imagekey': 'ImageKey',
       'passwordhash': 'PasswordHash'}

  ### methods Value:
      set(['smugmug.albums.applyWatermark',
           'smugmug.albums.changeSettings',
           'smugmug.albums.create',
           'smugmug.albums.delete',
           'smugmug.albums.get',
           'smugmug.albums.getInfo',
           'smugmug.albums.getStats',
           'smugmug.albums.reSort',
      ...